@@ -1,5 +1,5 @@
 package Text::Xslate::Syntax::TTerse;
-use Any::Moose;
+use Mouse;
 use Text::Xslate::Util qw(p any_in);
 use Scalar::Util ();
 
@@ -602,7 +602,7 @@ sub std_filter {
     return( $proc, $parser->print($callfilter) );
 }
 
-no Any::Moose;
+no Mouse;
 __PACKAGE__->meta->make_immutable();
 __END__
 
@@ -695,8 +695,8 @@ Loop iterators are partially supported.
         * [% loop.body      # alias to arrayref %]
         * [% loop.size      # loop.body.size %]
         * [% loop.max_index # loop.size - 1 %]
-        * [% loop.peek_next # loop.body[ loop.index - 1 ]
-        * [% loop.peek_prev # loop.body[ loop.index + 1 ]
+        * [% loop.peek_next # loop.body[ loop.index + 1 ]
+        * [% loop.peek_prev # loop.body[ loop.index - 1 ]
         [%- IF loop.is_last -%]
         <last>
         [%- END -%]
